@@ -1,25 +1,8 @@
 # -------------------------------------------------------------------------------------
 # MKDoc::Config
 # -------------------------------------------------------------------------------------
-# Author : Jean-Michel Hiver.
-# Copyright : (c) MKDoc Holdings Ltd., 2003.
-#
-# This file is part of MKDoc. 
-# 
-# MKDoc is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-# 
-# MKDoc is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with MKDoc; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
+# Author : Jean-Michel Hiver <jhiver@mkdoc.com>.
+# Copyright : (c) Jean-Michel Hiver, 2003.
 # -------------------------------------------------------------------------------------
 package MKDoc::Config;
 use strict;
@@ -189,21 +172,6 @@ sub TEMPLATE_DIR2
 }
 
 
-sub LANGUAGE_LIST
-{
-    my $class = shift;
-    return get_env ('MKD__LANGUAGE_LIST') || $class->MKDOC_DIR . '/conf/languages.conf';
-}
-
-
-sub LANGUAGE_LIST_RTL
-{
-    my $class = shift;
-    return get_env ('MKD__LANGUAGE_LIST_RTL') || $class->MKDOC_DIR . '/conf/languages_rtl.conf';
-}
-
-
-
 sub XHTML_FILTER_LIST
 {
     my $class = shift;
@@ -246,18 +214,13 @@ sub CACHE_DIR          { return get_env ('MKD__GLOBAL_CACHE_DIR') ||
                                 get_env ('MKD__CACHE_DIR')        ||
                                 MKDoc::Config->SITE_DIR . '/cache' }
 
-sub DATA_DIR          { MKDoc::Config->SITE_DIR . '/data'  }
+sub DATA_DIR           { MKDoc::Config->SITE_DIR . '/data'  }
 
 sub FILE_DISK_PATH     { get_env ('MKD__GLOBAL_FILE_DISK_PATH')         || MKDoc::Config->SITE_DIR . '/static/files'  }
 sub IMAGE_DISK_PATH    { get_env ('MKD__GLOBAL_IMAGE_DISK_PATH')        || MKDoc::Config->SITE_DIR . '/static/images' }
 sub FILE_HTTP_PATH     { get_env ('MKD__GLOBAL_FILE_HTTP_PATH')         || '/.static/files'                           }
 sub IMAGE_HTTP_PATH    { get_env ('MKD__GLOBAL_IMAGE_HTTP_PATH')        || '/.static/images'                          }
 
-sub EXTERNAL_LINKS_OPEN_IN_NEW_WINDOW
-{
-    my $class = shift;
-    return get_env ('MKD__EXTERNAL_LINKS_OPEN_IN_NEW_WINDOW') || 0;
-}
 
 ##
 # $class->new ($prefix);
@@ -266,7 +229,7 @@ sub EXTERNAL_LINKS_OPEN_IN_NEW_WINDOW
 ##
 sub new
 {
-    $::MKD_CONFIG = { _make_config() } unless $::MKD_CONFIG->{'do_i_really_exist'};
+    $::MKD_CONFIG ||= { _make_config() };
     
     my $class = shift;
     $class = ref $class || $class;
@@ -277,13 +240,11 @@ sub new
 
 
 sub _make_config {
-    'do_i_really_exist'                             => '',
     'flo.plugin.Discussion.List.slice_thickness'    => get_env ('MKD__PLUGIN_DISCUSSION_PER_PAGE')  || 50,
     'flo.plugin.Photo.scaled_max_x'                 => get_env ('MKD__PLUGIN_PHOTO_SCALED_X')       || 512,
     'flo.plugin.Photo.scaled_max_y'                 => get_env ('MKD__PLUGIN_PHOTO_SCALED_Y')       || 384,
     'flo.plugin.Photo.thumb_max_x'                  => get_env ('MKD__PLUGIN_PHOTO_THUMB_X')        || 256,
     'flo.plugin.Photo.thumb_max_y'                  => get_env ('MKD__PLUGIN_PHOTO_THUMB_Y')        || 128,
-    'flo.plugin.Photo.quality'                      => get_env ('MKD__PLUGIN_PHOTO_QUALITY')        || 50,
     'flo.plugin.Poll.cookie_name'                   => get_env ('MKD__PLUGIN_POLL_COOKIE')          || 'MKD_Poll_',
     'flo.plugin.Search.per_page'                    => get_env ('MKD__PLUGIN_SEARCH_PER_PAGE')      || 10,
     'flo.plugin.Sitemap.MAX_DEPTH'                  => get_env ('MKD__PLUGIN_SITEMAP_DEPTH')        || 2,
