@@ -1,31 +1,12 @@
 # -------------------------------------------------------------------------------------
 # flo::Component
 # -------------------------------------------------------------------------------------
-# Author : Jean-Michel Hiver
+# Author : Jean-Michel Hiver <jhiver@mkdoc.com>
 # Copyright : (c) MKDoc Holdings Ltd, 2002
-#
-# This file is part of MKDoc. 
-# 
-# MKDoc is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-# 
-# MKDoc is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with MKDoc; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
 # 
 # Discussion content component. Should let the user add hyperlinks to pages
 # -------------------------------------------------------------------------------------
 package flo::Component;
-use Cache::FileCache;
-use Data::Dumper;
 use MKDoc::XML::Dumper;
 use flo::Standard;
 use Encode;
@@ -211,9 +192,6 @@ sub new
 }
 
 
-sub _initialize {}
-
-
 sub cgi_args
 {
     my $self   = shift;
@@ -229,27 +207,6 @@ sub cgi_args
     return wantarray ? %hash : \%hash;
 }
 
-# variant of cgi_args which allows for multiple values in a single
-# param (i.e. from a multi-select).  This can probably replace
-# cgi_args but without an automated test suite it's impossible to be
-# sure something won't break.
-sub cgi_args_multi {
-    my $self   = shift;
-    my $cgi    = $self->{cgi} || return;
-    my $prefix = $self->{param_name} . '_';
-
-    my %hash;
-    foreach my $name ($cgi->param) {
-        my $key = $name;
-        next unless $key =~ s/^$prefix//;        
-        my @values = $cgi->param($name);
-        $hash{$key} = @values == 0 ? undef : 
-                      @values == 1 ? $values[0] : 
-                     \@values;
-    }
-
-    return wantarray ? %hash : \%hash;
-}
 
 sub link
 {
@@ -481,27 +438,6 @@ sub root
 }
 
 
-##
-# $self->links_for_tagger;
-# ------------------------
-#   Returns a list of links in a format suitable for tagging
-##
-sub links_for_tagger
-{
-    my $self = shift;
-    my @link = flo::Editor->links();
-    my @newl = ();
-    for (@link) {
-        my $new = { %{$_} };
-        $new->{_expr} = delete $new->{expr};
-        $new->{_tag}  = 'a';
-        $new->{title} = delete $new->{desc};
-        push @newl, $new;
-    }
-    return @newl;
-}
-
-
 ##
 # $self->is_only_child;
 # ---------------------
@@ -566,14 +502,13 @@ sub mkdoc_uri
 {
     my $self = shift;
     my $cgix = flo::Standard::cgi()->new;
-    $cgix->delete_all_fast();
+    $cgix->delete ($_) for ($cgix->param);
     $cgix->path_info ( $self->path );
     while (@_)
     {
 	my ($key, $val) = (shift, shift);
 	$cgix->param ($key, $val);
     }
-
     return $cgix->self_url;
 }
 
@@ -591,20 +526,6 @@ sub name
 }
 
 
-##
-# $self->name_is ($stuff);
-# -----------------------------
-# Returns TRUE if this component's name is $stuff,
-# FALSE otherwise.
-##
-sub name_is
-{
-    my $self = shift;
-    my $name = shift || '';
-    return lc ($self->name()) eq lc ($name);
-}
-
-
 ##
 # $self->generate_xml;
 # --------------------
@@ -639,67 +560,14 @@ sub parse_xml
     my $self = shift;
     eval {
         my $xml  = shift;
-        $xml = Encode::encode_utf8 ($xml);
-
-        my $obj  = $self->xml_cache_get ($xml) || do {
-            my $res = MKDoc::XML::Dumper->xml2perl ($xml);
-            $self->xml_cache_set ($xml, $res);
-            $res;
-        };
-
-        for (keys %{$obj})
-        {
-            $self->{$_} = Encode::decode_utf8  ($obj->{$_} );
-        }
-
+        my $obj  = MKDoc::XML::Dumper->xml2perl ($xml);
+        $self->{$_} = $obj->{$_} for (keys %{$obj});
         $self->__on_load() if ($self->can ('__on_load'));
     };
-
-    $@ and warn "== $@ ==";
+    # $@ and warn $@;
+    # Carp::cluck ($@);
 }
 
-# determine contents of the Move button target select list, correcting
-# for placement, minimum and maximum
-sub move_targets {
-    my $self   = shift;
-    my $editor = flo::Editor::_ETERNAL_(); 
-    my $count  = $editor->component_count();
-    my $pos    = $editor->component_position($self);
-    my $last   = $count - 1;
-
-    # setup available targets
-    my @targets;
-    push @targets, { label => 'to top', 
-                     value => 'top' }
-      if $pos != 0;
-    push @targets, { label => 'up 3', 
-                     value => '-3' }
-      if $pos > 2;
-    push @targets, { label => 'up 2', 
-                     value => '-2' }
-      if $pos > 1;
-    push @targets, { label       => 'up', 
-                     value       => '-1',
-                     is_selected => 1 }
-      if $pos > 0;
-    push @targets, { label => 'down', 
-                     value => '+1', 
-                     ($pos == 0 ? (is_selected => 1) : ()) }
-      if $pos < $last;
-    push @targets, { label => 'down 2', 
-                     value => '+2' }
-      if $pos < ($last - 1);
-    push @targets, { label => 'down 3', 
-                     value => '+3' }
-      if $pos < ($last - 2);
-    push @targets, { label => 'to bottom', 
-                     value => 'bottom' }
-      if $pos != $last;
-
-    return \@targets;
-}
-
-
 
 ##                                                               #
 #  ALL THESE DEFAULT TO THE PARENT DOCUMENT METHODS, BUT SHOULD  #
@@ -852,50 +720,4 @@ sub Direction
 }
 
 
-sub xml_cache_get
-{
-    my $self = shift;
-    my $xml  = shift;
-
-    $::MKD_XML_CACHE ||= {};
-    $::MKD_XML_CACHE->{$xml} ||= do {
-        my $obj  = $self->_xml_cache_object();
-        my $data = $obj->get ($xml) || return;
-        my $VAR1 = undef;
-        eval "$data";
-        $VAR1;
-    };
-
-    return $::MKD_XML_CACHE->{$xml};
-}
-
-
-sub xml_cache_set
-{
-    my $self = shift;
-    my $xml  = shift;
-    my $data = shift;
-
-    $::MKD_XML_CACHE ||= {};
-    $::MKD_XML_CACHE->{$xml} = $data;
-
-    my $obj  = $self->_xml_cache_object();
-    $data = Dumper ($data);
-    $obj->set ($xml, $data);
-}
-
-
-sub _xml_cache_object
-{
-    my $self = shift;
-    my %opt  = (
-        cache_root => MKDoc::Config->CACHE_DIR,
-        namespace  => 'component_xml',
-    );
-
-    return new Cache::FileCache ( \%opt );
-}
-
-
-
 1;
