@@ -2,26 +2,12 @@
 # flo::Record::Audience
 # -------------------------------------------------------------------------------------
 #
-#       Author : Jean-Michel Hiver,
+#       Author : Jean-Michel Hiver (jhiver@mkdoc.com),
 #                Steve Purkis <spurkis@mkdoc.com>
 #    Copyright : (c) MKDoc Holdings Ltd, 2002.
 #
-# This file is part of MKDoc. 
-# 
-# MKDoc is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-# 
-# MKDoc is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with MKDoc; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
+#       Unauthorized modification, use, reuse, distribution or redistribution
+#       of this module is stricly forbidden.
 #
 #    Description:
 #
@@ -62,7 +48,7 @@ use 5.008_000;
 ##
 
 ## Version (from CVS revision string).
-our $VERSION = (split(/ /, '$Revision: 1.7.2.6 $'))[1];
+our $VERSION = (split(/ /, '$Revision: 1.13 $'))[1];
 
 
 ## Boolean switch controlling debug printing to STDERR.
@@ -190,7 +176,7 @@ sub _filter_search_args
     }
     else
     {
-	# don't pass db fields that don't exist to lib::sql::Table
+	# don't pass db fields that don't exist to MKDoc::SQL::Table
 	for (keys %args)
 	{
 	    delete($args{$_}) unless ((/(ID)|(Value)|(Label)/)
@@ -207,7 +193,7 @@ sub _filter_search_args
 # $table = $class->table_handle;
 # ------------------------------
 #   See $TABLE_NAME.
-#   Returns the lib::sql::Table handle of this object.
+#   Returns the MKDoc::SQL::Table handle of this object.
 ##
 sub table_handle
 {
@@ -293,37 +279,6 @@ sub label
 }
 
 
-##
-# $short_label = $self->short_label;
-# --------------------
-#   Returns the 'Label' attribute stripped of anything
-#   that could be considered a category name.
-##
-sub short_label
-{
-    my $self = shift;
-    my $label = $self->{Label};
-    $label =~ s/[^:]*: *//;
-    return $label;
-}
-
-
-##
-# $category = $self->category;
-# --------------------
-#   Returns the 'Label' attribute stripped of anything
-#   but what could be considered a category name.
-##
-sub category
-{
-    my $self = shift;
-    my $label = $self->{Label};
-    return '' unless $label =~ /:/;
-    $label =~ s/ *:.*//;
-    return $label;
-}
-
-
 ##
 # $obj = $obj->set_label ($label);
 # --------------------------------
