@@ -1,26 +1,9 @@
 # -------------------------------------------------------------------------------------
 # flo::Record::Document
 # -------------------------------------------------------------------------------------
-# Author : Jean-Michel Hiver.
+# Author : Jean-Michel Hiver (jhiver@mkdoc.com).
 # Copyright : (c) MKDoc Holdings Ltd, 2003.
 #
-# This file is part of MKDoc. 
-# 
-# MKDoc is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-# 
-# MKDoc is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with MKDoc; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-#
 # This class models MKDoc document objects, and holds methods related to document
 # hierarchy and metadata validation.
 # -------------------------------------------------------------------------------------
@@ -82,7 +65,7 @@ sub showable_class
 ##
 # $self->is_showable()
 # --------------------
-# Returns FALSE if this object is hidden or a versioned backup, TRUE otherwise.
+# Returns TRUE if this object is hidden, FALSE otherwise.
 ##
 sub is_showable
 {
@@ -92,21 +75,6 @@ sub is_showable
 		 $self->is_deleted_version() );
 }
 
-=pod
-
-  $self->is_showable_to_editor()
-
-Returns FALSE if this object is a versioned backup, TRUE otherwise.
-
-=cut
-
-sub is_showable_to_editor
-{
-    my $self = shift;
-    return not ( $self->is_modified_version() ||
-		 $self->is_deleted_version() );
-}
-
 
 ##
 # $self->is_hidden();
@@ -122,6 +90,13 @@ sub is_hidden
 }
 
 
+sub is_versioned
+{
+    my $self = shift;
+    return $self->is_modified_version() || $self->is_deleted_version();
+}
+
+
 ##
 # $self->is_modified();
 # ---------------------
@@ -130,7 +105,7 @@ sub is_hidden
 sub is_modified_version
 {
     my $self = shift;
-    my $path = $self->path();
+    my $path = "/" . $self->uri_name() . "/";
     my $re   = MKDoc::Config->URI_MODIFIED_REGEX;
     return $path =~ /$re/;
 }
@@ -144,7 +119,7 @@ sub is_modified_version
 sub is_deleted_version
 {
     my $self = shift;
-    my $path = $self->path();
+    my $path = "/" . $self->uri_name() . "/";
     my $re   = MKDoc::Config->URI_DELETED_REGEX;
     return $path =~ /$re/;
 }
@@ -166,13 +141,13 @@ sub is_root
 
 
 ##
-# $self->first();
+# $self->_first();
 # ---------------
 # Returns the first sibling. If this document has no
 # sibling, is the first sibling, or is an only child,
 # returns undef.
 ##
-sub first
+sub _first
 {
     my $self = shift;
     
@@ -200,6 +175,20 @@ sub first
 }
 
 
+##
+# $self->first();
+# ------------------------
+# Returns the first document, if any.
+##
+sub first
+{
+    my $self  = shift;
+    my $first = $self->_first() || return;
+    return $first unless ($first->is_versioned());
+    return $first->next();
+}
+
+
 ##
 # $self->first_showable();
 # ------------------------
@@ -215,13 +204,13 @@ sub first_showable
 
 
 ##
-# $self->last();
-# --------------
-# Returns the first sibling. If this document has no
-# sibling, is the first sibling, or is an only child,
+# $self->_last();
+# ---------------
+# Returns the last sibling. If this document has no
+# sibling, is the last sibling, or is an only child,
 # returns undef.
 ##
-sub last
+sub _last
 {
     my $self = shift;
     
@@ -250,6 +239,20 @@ sub last
 }
 
 
+##
+# $self->last();
+# --------------
+# Returns the last document, if any.
+##
+sub last
+{
+    my $self  = shift;
+    my $last = $self->_last() || return;
+    return $last unless ($last->is_versioned());
+    return $last->prev();
+}
+
+
 ##
 # $self->last_showable();
 # ------------------------
@@ -270,7 +273,7 @@ sub last_showable
 # Returns the next sibling related to this document.
 # If the document has no next sibling, returns undef.
 ##
-sub next
+sub _next
 {
     my $self = shift;
     exists $self->{'.next'} and return $self->{'.next'};
@@ -289,6 +292,20 @@ sub next
 }
 
 
+##
+# $self->next();
+# -----------------------
+# Returns the next sibling.
+##
+sub next
+{
+    my $self = shift;
+    my $next = $self->_next() || return;
+    return $next unless ($next->is_versioned());
+    return $next->next();
+}
+
+
 ##
 # $self->next_showable();
 # -----------------------
@@ -304,12 +321,12 @@ sub next_showable
 
 
 ##
-# $self->prev();
-# --------------
+# $self->_prev();
+# ---------------
 # Returns the previous sibling related to this document.
 # If the document has no previous sibling, returns undef.
 ##
-sub prev
+sub _prev
 {
     my $self = shift;
     exists $self->{'.prev'} and return $self->{'.prev'};
@@ -328,6 +345,20 @@ sub prev
 }
 
 
+##
+# $self->prev();
+# -----------------------
+# Returns the previous sibling.
+##
+sub prev
+{
+    my $self = shift;
+    my $prev = $self->_prev() || return;
+    return $prev unless ($prev->is_versioned());
+    return $prev->prev();
+}
+
+
 ##
 # $self->prev_showable();
 # -----------------------
@@ -413,7 +444,7 @@ sub new
     $self->set_name ($self->_find_name ($self->name() || $self->title()));
     if ($self->validate())
     {
-	$self->save();
+	$self->_save();
 	return $self;
     }
     
@@ -427,6 +458,46 @@ sub new
 # Saves the current document. Warning, does not perform any validation.
 ##
 sub save
+{
+    my $self = shift;
+    $self->id() || do {
+        warn "Deprecated - use $self->_save() to INSERT a document.";
+        return;
+    };
+
+    $self->backup();
+    $self->_save();
+}
+
+
+sub backup
+{
+    my $self = shift;
+    my $id   = $self->id();
+
+    my $doc_t    = flo::Standard::table ('Document');
+    my $old_self = $doc_t->get ($id);
+    
+    my $parent_path = $old_self->path();
+    my $new_name    = $self->_modified_name_now();
+    my $new_path    = $parent_path . $new_name . '/';
+
+    while ($doc_t->get (Full_Path => $new_path))
+    {
+        sleep (1);
+        $new_name = $self->_modified_name_now();
+        $new_path = $parent_path . $new_name . '/';
+    }
+   
+    delete $old_self->{ID};
+    delete $old_self->{Full_Path};
+    $old_self->set_parent_id ($id);
+    $old_self->set_name ($new_name);
+    $old_self->_save();
+}
+
+
+sub _save
 {
     my $self = shift;
     my $document_t = flo::Standard::table ('Document');
@@ -451,15 +522,21 @@ sub delete
 {
     my $self = shift;    
     $self->is_root() and return;
-
-    # call delete handler
-    $self->on_delete();
     
-    $_->delete() for ($self->children());
-    $self->_delete_redirect (@_);
-    $self->_delete_base_doc (@_);
-    $self->_delete_self (@_);
-    return 1;
+    my $document_t  = flo::Standard::table ('Document');
+    my $parent_path = $self->parent()->path();
+    my $new_name    = $self->_deleted_name_now();
+    my $new_path    = $parent_path . $new_name . '/';
+
+    while ($document_t->get (Full_Path => $new_path))
+    {
+        sleep (1);
+        $new_name = $self->_deleted_name_now();
+        $new_path = $parent_path . $new_name . '/';
+    }
+
+    $self->set_name ($new_name);
+    $self->_save(); 
 }
 
 
@@ -500,7 +577,7 @@ sub copy_to__shallow_overwrite
     $child->set_name ($name);
     $child->set_date_created ($dc);
     $child->set_editor_created_id ($eci);
-    $child->save();
+    $child->_save();
     return $child;
 }
 
@@ -678,7 +755,7 @@ sub move_to
     
     flo::RedirectManager->document_moved ($self, $parent->path());
     $self->set_parent ($parent);
-    $self->save();
+    $self->_save();
 }
 
 
@@ -1107,21 +1184,6 @@ sub ancestors
 }
 
 
-##
-# $self->root_child();
-# --------------------
-# Returns the ancestor of this document that is a child of the root document.
-##
-sub root_child 
-{
-    my $self = shift;
-    my $ancestors = $self->ancestors;
-    return unless $ancestors;
-    return $self unless $ancestors->[1];
-    return $ancestors->[1];
-}
-
-
 ##
 # $self->position();
 # ------------------
@@ -1477,7 +1539,7 @@ sub available_langs
     my $self    = shift;
     my $default = shift || $self->lang || 'en';
 
-    my $cfg = new MKDoc::Config->parsefile_hashref (MKDoc::Config->LANGUAGE_LIST);
+    my $cfg = MKDoc::Core::Language->as_hash();
     my @res = sort { $cfg->{$a} cmp $cfg->{$b} } keys %{$cfg};
     return (wantarray) ? @res : \@res;
 }
@@ -1485,29 +1547,15 @@ sub available_langs
 
 sub used_langs
 {
-    my $class = shift;
-    my $sql   = <<'EOF';
-SELECT DISTINCT (Lang)
-FROM Document
-WHERE Name NOT LIKE 'deleted-____-__-__-__-__-__'  AND
-      Name NOT LIKE 'modified-____-__-__-__-__-__' AND
-      Name NOT LIKE 'private-%'                    AND
-      Name NOT LIKE 'hidden-%'
-EOF
+    my $class          = shift;
+    my $document_table = flo::Standard::table ('Document');
+    my $query          = $document_table->select (
+	distinct => 1,
+	cols     => 'Lang',
+       );
     
-    my $dbh = lib::sql::DBH->get();
-    $dbh->prepare ($sql);
-
-    my @res = ();
-
-    my $sth = $dbh->prepare ($sql);
-    $sth->execute();
-    while (my $array_ref = $sth->fetchrow_arrayref())
-    {
-        push @res, $array_ref->[0];
-    }
-
-    return wantarray ? @res : \@res;
+    my @langs = map { $_->{Lang} } $query->fetch_all;
+    return @langs;
 }
 
 
@@ -1515,7 +1563,7 @@ sub lang_label
 {
     my $self = shift;
     my $lang = shift || $self->language;
-    my $hash = MKDoc::Config->parsefile_hashref (MKDoc::Config->LANGUAGE_LIST);
+    my $hash = MKDoc::Core::Language->as_hash();
     return exists $hash->{$lang} ? $hash->{$lang} : return;
 }
 
@@ -1658,8 +1706,10 @@ sub set_sort_method
 sub validate_sort_method
 {
     my $self = shift;
-    $self->sort_method() || $self->set_sort_method (SORT_METHOD_TITLE);
-    return 1;
+    return 1 if ($self->sort_method);
+    
+    new MKDoc::Ouch ( 'document/sort' );
+    return 0;
 }
 
 
@@ -1668,7 +1718,7 @@ sub validate_sort_method
 # ----------------
 # Returns a list of all sub-documents held by that document
 ##
-sub children
+sub _children
 {
     my $self = shift;
     my $args = { @_ };
@@ -1680,9 +1730,6 @@ sub children
 					      sort  => [ $sort_by ],
 					      desc  => ($self->order_by) ? 1 : 0 );
 	my $children = $query->fetch_all;
-	
-	# my @children = map { $_->is_showable() ? $_ : () } @{$children};
-	# \@children;
 	$children;
     };
     
@@ -1698,6 +1745,31 @@ sub children
 }
 
 
+sub children
+{
+    my $self = shift;
+    my @res  = map { ! $_->is_versioned() ? $_ : () } $self->_children;
+    return wantarray ? @res : \@res;
+}
+
+
+sub children_modified
+{
+    my $self = shift;
+    my @res  = map { $_->is_modified_version() ? $_ : () } $self->_children;
+    @res = sort { $b->uri_name() cmp $a->uri_name() } @res;
+    return wantarray ? @res : \@res;
+}
+
+
+sub children_deleted
+{
+    my $self = shift;
+    my @res  = map { $_->is_deleted_version() ? $_ : () } $self->_children;
+    return wantarray ? @res : \@res;
+}
+
+
 ##
 # $self->children_showable();
 # ---------------------------
@@ -1706,41 +1778,17 @@ sub children
 sub children_showable
 {
     my $self = shift;
-    my @res;
-    if (flo::Standard::current_user && flo::Standard::current_user->is_editor)
-    {
-        @res  = map { $_->is_showable_to_editor() ? $_ : () } $self->children;
-    }
-    else
-    {
-        @res  = map { $_->is_showable() ? $_ : () } $self->children;
-    }
+    my @res  = map { $_->is_showable() ? $_ : () } $self->children();
     return wantarray ? @res : \@res;
 }
 
 
-##
-# $self->children_showable_percent_each()
-# ---------------------------------------
-# returns 25% if there are 4 children, 12.5% if there are eight etc..
-# css percentages are decimal numbers, not necessarily integers
-# http://www.w3.org/TR/REC-CSS2/syndata.html#value-def-number
-##
-sub children_showable_percent_each
-{
-    my $self = shift;
-    my $children_showable = $self->children_showable;
-    my $number = @$children_showable || return;
-    return (100 / $number) . '%';
-}
-
-
 ##
 # $self->cousins_homonyms();
 # --------------------------
 # Returns a list of cousins which are also homonyms.
 ##
-sub cousin_homonyms
+sub _cousin_homonyms
 {
     my $self = shift;
     my $self_id        = $self->id();
@@ -1758,7 +1806,7 @@ WHERE Name = ?
 ORDER BY Full_Path ASC
 EOF
     
-    my $dbh = lib::sql::DBH->get();
+    my $dbh = MKDoc::SQL::DBH->get();
     my $sth = $dbh->prepare_cached ($sql);
     $sth->execute ($self_name);
     
@@ -1783,6 +1831,14 @@ EOF
 }
 
 
+sub cousin_homonyms
+{
+    my $self = shift;
+    my @res  = map { ! $_->is_versioned() ? $_ : () } $self->_cousin_homonyms();
+    return wantarray ? @res : \@res;
+}
+
+
 ##
 # $self->cousin_homonyms_showable();
 # ----------------------------------
@@ -1816,7 +1872,7 @@ sub _homonyms_objectify
 # Returns a list of documents which have the same name
 # as this document.
 ##
-sub homonyms
+sub _homonyms
 {
     my $self = shift;
     my $args = { @_ };
@@ -1836,6 +1892,14 @@ sub homonyms
 }
 
 
+sub homonyms
+{
+    my $self = shift;
+    my @res  = map { ! $_->is_versioned() ? $_ : () } $self->_homonyms();
+    return wantarray ? @res : \@res;
+}
+
+
 ##
 # $self->homonyms_showable();
 # ---------------------------
@@ -2292,8 +2356,9 @@ sub is_only_child
 {
     my $self = shift;
     return 1 unless (defined $self->parent_id); 
-    my @siblings = $self->parent->children (@_); 
-    return @siblings == 1;
+    my @siblings = $self->parent->children (@_);
+    @siblings = map { ! $_->is_versioned() ? $_ : () } @siblings; 
+    return @siblings < 2;
 }
 
 
@@ -2321,6 +2386,7 @@ sub is_only_homonym
     my $self = shift;
     return 1 unless (defined $self->parent_id); 
     my @list = $self->homonyms (@_);
+    @list = map { ! $_->is_versioned() ? $_ : () } @list; 
     return @list == 1;
 }
 
@@ -2349,6 +2415,7 @@ sub is_only_cousin_homonym
     my $self = shift;
     return 1 unless (defined $self->parent_id); 
     my @list = $self->cousin_homonyms (@_);
+    @list = map { ! $_->is_versioned() ? $_ : () } @list; 
     return @list == 1;
 }
 
@@ -2377,6 +2444,7 @@ sub cousin_homonym
 {
     my $self = shift;
     my @list = $self->cousin_homonyms (@_);
+    @list = map { ! $_->is_versioned() ? $_ : () } @list; 
     return $list[0];
 }
 
@@ -2405,6 +2473,7 @@ sub homonym
 {
     my $self = shift;
     my @list = $self->homonyms (@_);
+    @list = map { ! $_->is_versioned() ? $_ : () } @list; 
     return $list[0];
 }
 
@@ -2459,7 +2528,7 @@ sub align_opposite
 sub direction
 {
     my $self = shift;
-    my $hash = MKDoc::Config->parsefile_hashref (MKDoc::Config->LANGUAGE_LIST_RTL);
+    my $hash = MKDoc::Core::Language->as_hash_rtl();
     my $lang = $self->language();
     return exists $hash->{$lang} ? 'rtl' : 'ltr';
 }
@@ -2606,6 +2675,24 @@ sub Can_Admin
 }
 
 
+sub _deleted_name_now
+{
+    my $now = now_iso();
+    $now =~ s/\:/-/g;
+    $now =~ s/\s/-/g;
+    return "deleted-$now";
+}
+
+
+sub _modified_name_now
+{
+    my $now = now_iso();
+    $now =~ s/\:/-/g;
+    $now =~ s/\s/-/g;
+    return "modified-$now";
+}
+
+
 sub now_iso
 {
     my @time  = localtime (time());
@@ -2648,33 +2735,5 @@ sub now_time_iso
     return $time;
 }
 
-##
-# $self->on_save;
-#
-# Handler which gets called just before saving the document.  Needed
-# to clean up index tables, like Document_TimeRange.
-##
-sub on_save {
-    my $self = shift;
-    my $id   = $self->id();
-
-    # new documents won't need pre-save cleanup
-    return unless $id;
-
-    my $dbh = lib::sql::DBH->get();
-    $dbh->do('DELETE FROM Document_TimeRange WHERE Document_ID = ?',
-             undef, $id);
-}
-
-##
-# $self->on_delete;
-#
-# Handler which gets called just before deleting the document.  Needed
-# to clean up index tables, like Document_TimeRange.
-##
-sub on_delete {
-    my $self = shift;
-    $self->on_save();
-}
 
 1;
