@@ -1,25 +1,8 @@
 # -------------------------------------------------------------------------------------
 # flo::Record::Editor
 # -------------------------------------------------------------------------------------
-# Author : Jean-Michel Hiver.
+# Author : Jean-Michel Hiver <jhiver@mkdoc.com>.
 # Copyright : (c) MKDoc Holdings Ltd, 2003.
-#
-# This file is part of MKDoc. 
-# 
-# MKDoc is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-# 
-# MKDoc is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with MKDoc; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
 # -------------------------------------------------------------------------------------
 package flo::Record::Editor;
 use flo::Standard;
@@ -29,6 +12,7 @@ use Digest::MD5;
 use strict;
 use 5.008_000;
 use utf8;
+use vars qw /$HAVE_CHECKMAIL/;
 
 
 $Petal::Hash::MODIFIERS->{'user_root:'} = sub {
@@ -38,6 +22,13 @@ $Petal::Hash::MODIFIERS->{'user_root:'} = sub {
 };
 
 
+BEGIN
+{
+    eval "use Mail::CheckUser";
+    $HAVE_CHECKMAIL = 1 unless ($@);
+}
+
+
 ##
 # $class->new (%args);
 # --------------------
@@ -53,7 +44,6 @@ sub new
     if ($self->validate())
     {
 	$self->save();
-        $self->preferences->set_default_language;
 	return $self;
     }
     
@@ -516,6 +506,17 @@ sub validate_email
 	return 0;
     };
     
+    if ($HAVE_CHECKMAIL)
+    {
+	$Mail::CheckUser::Timeout = 5;
+	$Mail::CheckUser::Treat_Timeout_As_Fail = undef;
+	$Mail::CheckUser::Treat_Full_As_Fail = undef;
+	Mail::CheckUser::check_email ($mail) || do {
+	    new MKDoc::Ouch 'user/email/advanced_checks';
+	    return 0;
+	};
+    }
+    
     return 1;
 }
 
