@@ -5,22 +5,8 @@
 #       Author : Steve Purkis <spurkis@mkdoc.com>
 #    Copyright : (c) 2002, MKDoc Holdings Ltd.
 #
-# This file is part of MKDoc. 
-# 
-# MKDoc is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-# 
-# MKDoc is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with MKDoc; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
+#      Unauthorized modification, use, reuse, distribution or redistribution
+#      of this module is stricly forbidden.
 #
 # -------------------------------------------------------------------------------------
 
@@ -52,7 +38,7 @@ flo::Record::Ticket - OO interface to the I<Tickets> table.
 
 
  # to look up a range of tickets, use
- # flo::Standard and lib::sql::Table
+ # flo::Standard and MKDoc::SQL::Table
 
 =head1 DESCRIPTION
 
@@ -72,7 +58,7 @@ Exceptions are not dealt with at this level.
 
 package flo::Record::Ticket;
 use flo::Standard qw /general_config cgi path_info raw_path_info table template current_document/;
-use lib::sql::Condition;
+use MKDoc::SQL::Condition;
 
 use Time::Local;
 
@@ -158,7 +144,7 @@ sub new {
     if ($id) {
 	$self = load_ticket_from_db($id) || return;
     } else {
-	# avoid clobbering lib::sql::Table's bless_into, just in case
+	# avoid clobbering MKDoc::SQL::Table's bless_into, just in case
 	bless $self, $class;
     }
 
@@ -297,7 +283,7 @@ sub _filter_search_args
     # convert Expiry into ExpiryDate (Expiry doesn't exist in this table)
     $args{ExpiryDate} = delete $args{Expiry} if (exists $args{Expiry});
 
-    # don't pass db fields that don't exist to lib::sql::Table
+    # don't pass db fields that don't exist to MKDoc::SQL::Table
     for (keys %args) {
 	delete($args{$_}) unless ((/(ID)|(Email)|(ExpiryDate)|(Action)/)
 				  and (defined $args{$_}));
@@ -327,9 +313,9 @@ sub clear_old_tickets_from_db {
     # reap old tickets, flo::Standard stylee
     my $ticket_table = table('Tickets') || return;;
 
-    # note: using NOW() doesn't work (it's quoted by lib::sql::Condition) so
+    # note: using NOW() doesn't work (it's quoted by MKDoc::SQL::Condition) so
     # we use a mysql date string
-    my $cond = new lib::sql::Condition;
+    my $cond = new MKDoc::SQL::Condition;
     $cond->add('ExpiryDate', '<', time_as_sql_date(time));
     my $deleted = $ticket_table->delete($cond);
 
@@ -403,7 +389,7 @@ sub sql_date_as_time {
 
 See $TABLE_NAME.
 
-Returns the lib::sql::Table handle of this object.
+Returns the MKDoc::SQL::Table handle of this object.
 
 =cut
 
