@@ -5,22 +5,8 @@
 #       Author : Steve Purkis <spurkis@mkdoc.com>
 #    Copyright : (c) MKDoc Holdings Ltd, 2002.
 #
-# This file is part of MKDoc. 
-# 
-# MKDoc is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-# 
-# MKDoc is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with MKDoc; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
+#       Unauthorized modification, use, reuse, distribution or redistribution
+#       of this module is stricly forbidden.
 #
 #    Description:
 #
@@ -45,7 +31,7 @@
 #       my $prefs = new flo::User::Preferences( User => $user );
 #
 #       my @langs = $prefs->language_names;
-#       $prefs->set_language_preference($langs[0], LIKE);
+#       $prefs->set_language_preference($langs[0], LIKES);
 #
 #       my @gens = $prefs->general_names;
 #       my $val  = $prefs->general_preference($gens[4]);
@@ -65,7 +51,6 @@ use flo::Record::Audience;
 
 use flo::Record::Document;
 
-use MKDoc;
 use MKDoc::Config;
 
 use Exporter;
@@ -89,7 +74,7 @@ use base qw/ Exporter /;
 ##
 
 ## Version (from CVS revision string).
-our $VERSION = (split(/ /, '$Revision: 1.11.2.14 $'))[1];
+our $VERSION = (split(/ /, '$Revision: 1.20 $'))[1];
 
 
 ## Boolean switch controlling debug printing to STDERR.
@@ -408,13 +393,17 @@ sub _create_general_pref ($$)
 sub generals($)
 {
     my $self = shift;
-    my @generals = (
-        { 'name' => 'newsletter-daily',   'label' => 'newsletter-daily' },
-        { 'name' => 'newsletter-monthly', 'label' => 'newsletter-monthly' },
-        { 'name' => 'newsletter-weekly',  'label' => 'newsletter-weekly' }
-    );
-    
-    return wantarray ? @generals : \@generals; 
+    my @GENERALS;
+
+    unless (exists $self->{_generals_})
+    {
+	my $cfg      = new MKDoc::Config('User.Preferences.general');
+	my %GENERALS = $cfg->hash;
+	@GENERALS    = 	map { { name => $_, label => $GENERALS{$_} } } sort keys %GENERALS;
+	$self->{_generals_} = [ @GENERALS ];
+    }
+
+    return wantarray ? @{$self->{_generals_}} : $self->{_generals_};
 }
 
 
@@ -445,19 +434,6 @@ sub general_name_exists($)
 }
 
 
-##
-# $obj->set_default_language;
-# ---------------------------
-#   If there is only one language in use, sets language preference to that,
-#   otherwise does nothing.
-##
-sub set_default_language
-{
-    my $self = shift;
-    my @langs = $self->language_names;
-    $self->set_language_preference ($langs[0], LIKE) if (scalar @langs == 1);
-}
-
 
 ##
 # $val = $obj->language_preference($name);
@@ -539,7 +515,7 @@ sub languages($)
 
     unless (exists $self->{_languages_})
     {
-	my $phash = new MKDoc::Config->parsefile_hashref (MKDoc::Config->LANGUAGE_LIST);
+	my $phash = MKDoc::Core::Language->as_hash();
 	my @used_langs = flo::Record::Document->used_langs;
 	@LANGUAGES = map { { name => $_, label => $phash->{$_} } } sort @used_langs;
 	$self->{_languages_} = [ @LANGUAGES ];
@@ -677,7 +653,7 @@ sub audience_by_id($$)
 # @auds = $obj->audiences;
 # ------------------------
 #   Returns a list of all flo::Record::Audience objects available
-#   to be set, ordered by label, or undef on error.
+#   to be set, ordered by name, or undef on error.
 ##
 sub audiences($)
 {
@@ -687,61 +663,13 @@ sub audiences($)
     unless (exists $self->{_audiences_})
     {
 	my @auds   = load flo::Record::Audience( All => 1 );
-	@AUDIENCES = sort { $a->label cmp $b->label } @auds;
+	@AUDIENCES = sort { $a->name cmp $b->name } @auds;
 	$self->{_audiences_} = [@AUDIENCES];
     }
 
     return wantarray ? @{$self->{_audiences_}} : $self->{_audiences_};
 }
 
-##
-# @audiences = $obj->audience_categories();
-# ------------------------------------
-#   Returns a sorted list of all audience categories.
-#   Categories are implicit when a 'label' has ':' in it.
-#   Otherwise items will be in category ''.
-##
-sub audience_categories
-{
-    my $self = shift;
-
-    my $categories;
-    for my $audience (@{$self->audiences})
-    {
-        $categories->{$audience->category} = undef;
-    }
-
-    my @audience_categories;
-    for (keys %{$categories}) { push @audience_categories, $_ };
-
-    @audience_categories = sort { $a cmp $b } @audience_categories;
-
-    return wantarray ? @audience_categories : [@audience_categories];
-}
-
-##
-# @auds = $obj->audiences_by_category ('Fruit');
-# ------------------------
-#   Returns a list of all flo::Record::Audience objects available
-#   to be set that match the specified category, ordered by label, or undef on error.
-##
-sub audiences_by_category
-{
-    my $self = shift;
-    my $category = shift;
-
-    my @AUDIENCES;
-    my @AUDIENCE_BY_CATEGORY;
-
-    my @auds   = $self->audiences;
-    @AUDIENCES = sort { $a->label cmp $b->label } @auds;
-    for (@AUDIENCES)
-    {
-        push @AUDIENCE_BY_CATEGORY, $_ if $_->category eq $category;
-    }
-
-    return wantarray ? @AUDIENCE_BY_CATEGORY : [@AUDIENCE_BY_CATEGORY];
-}
 
 ##
 # @audiences = $obj->audience_names();
@@ -922,12 +850,7 @@ sub _load_audience_prefs($)
 {
     my $self  = shift;
     my @prefs = load flo::Record::Preference::Audience(User => $self->user);
-    my @ok_prefs = ();
-    for (@prefs)
-    {
-        push (@ok_prefs, $_) if ($self->audience_by_id($_->audience_id));
-    }
-    my %hash  = map { $self->audience_by_id($_->audience_id)->name => $_ } @ok_prefs;
+    my %hash  = map { $self->audience_by_id($_->audience_id)->name => $_ } @prefs;
     $self->_set_audience_prefs(\%hash);
 }
 
@@ -943,7 +866,7 @@ sub is_selected
     my $self = shift;
     my $name = shift;
     my $preference_t = flo::Standard::table ('Preference');
-    my $preference = $preference_t->get (Name => $name, Editor_ID => $self->user()->id()) || return;
+    my $preference = $preference_t->get (Name => $name) || return;
     $preference->{Value} ? return 'selected' : return;
 }
 
