@@ -1,30 +1,12 @@
 # -------------------------------------------------------------------------------------
 # flo::editor::Html
 # -------------------------------------------------------------------------------------
-# Author : Jean-Michel Hiver.
+# Author : Jean-Michel Hiver <jhiver@mkdoc.com>.
 # Copyright : (c) MKDoc Holdings Ltd, 2003
-#
-# This file is part of MKDoc. 
-# 
-# MKDoc is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-# 
-# MKDoc is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with MKDoc; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
 # -------------------------------------------------------------------------------------
 package flo::editor::Html;
 use flo::Standard;
 use flo::Editor;
-use lib::util::Command;
 use MKDoc::Util::Text2HTML;
 use MKDoc::Config;
 use strict;
@@ -103,7 +85,7 @@ sub parse_xml
 }
 
 
-sub as_xhtml { return "<div class=\"html\">" . shift()->html() . "</div>" }
+sub as_xhtml { return "<div>" . shift()->html() . "</div>" }
 
 
 ##
@@ -116,7 +98,16 @@ sub html
     my $self = shift;
     my $data = $self->{data};
 
-    my @newl = $self->links_for_tagger();
+    my @link = flo::Editor->links();
+    my @newl = ();
+    for (@link) {
+        my $new = { %{$_} };
+        $new->{_expr} = delete $new->{expr};
+        $new->{_tag}  = 'a';
+        $new->{title} = delete $new->{desc};
+        push @newl, $new;
+    }
+    
     return MKDoc::XML::Tagger::Preserve->process_data (['a'], $data, @newl);
 }
 
@@ -149,8 +140,9 @@ sub validate
 	my $tidied_data = $self->html_tidy;
 	$self->{data} = $tidied_data;
     };
-    
+   
     (defined $@ and $@) and do {
+        warn $@;
 	new MKDoc::Ouch 'component/html/untidy';
 	return 0;
     };
@@ -159,6 +151,56 @@ sub validate
 }
 
 
+sub sysexec($$$)
+{
+    my $cmd = shift;
+    my $tmp_dir = shift;
+    my $in  = shift;
+    Encode::_utf8_off ($in);
+    
+    my $out = undef;
+    my $err = undef;
+    
+    my $tmp = $$ . '.' . time . '.' . int (rand (10000));
+    my $tmp_out = $tmp_dir . '/' . $tmp . '.out';
+    my $tmp_err = $tmp_dir . '/' . $tmp . '.err';
+    
+    if (defined $in)
+    {
+	# executes the command and writes to temp files
+	open FP, "|$cmd 2>$tmp_err >$tmp_out" or
+            die "Cannot open pipe to $cmd: $!";
+	print FP $in;
+	close FP;
+    }
+    else
+    {
+	# executes the command and writes to temp files
+	system ("$cmd 2>$tmp_err >$tmp_out") or
+	    die "Cannot exec $cmd: $!";
+	print FP $in;
+	close FP;
+    }
+    
+    # reads the command standard output
+    open (FP, $tmp_out) or
+	die "Cannot read-open file $tmp_out: $!";
+    $out = join '', <FP>;
+    close FP;
+    
+    # reads the command error output
+    open FP, "<$tmp_err" or
+        die "Cannot read-epen file $tmp_err: $!";
+    $err = join '', <FP>;
+    close FP;
+    
+    # tidy all the mess and returns $out and $err
+    unlink $tmp_out;
+    unlink $tmp_err;
+    return ($out, $err);
+}
+
+
 ##
 # $obj->html_tidy;
 # ----------------
@@ -186,3 +228,7 @@ sub html_tidy
 
 
 1;
+
+
+
+
