@@ -3,26 +3,8 @@
 # -------------------------------------------------------------------------------------
 # Author : Steve Purkis <spurkis@mkdoc.com>
 # Copyright : (c) 2003, MKDoc Holdings Ltd.
-#
-# This file is part of MKDoc. 
-# 
-# MKDoc is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-# 
-# MKDoc is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with MKDoc; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
 # -------------------------------------------------------------------------------------
 package flo::plugin::Account::Details;
-use flo::plugin::Account::Preferences;
 use flo::Standard qw /cgi/;
 use flo::HTTP::Header;
 use flo::Record::Ticket;
@@ -31,7 +13,6 @@ use MKDoc::Config;
 use Carp;
 use Petal;
 use Petal::Mail;
-use MKDoc::MailForm;
 
 use strict;
 use 5.008_000;
@@ -162,11 +143,6 @@ sub _initialize_cgi_fields_login_find_free_login
 sub http_post
 {
     my $self = shift;
-   
-    my $mailform = new MKDoc::MailForm (cgi => flo::Standard::cgi());
-    $mailform->process();
-    return $self->http_get if ($self->has_errors());
-
     $self->_validate_and_create_account();
     return $self->http_get if ($self->has_errors());
     
@@ -262,7 +238,7 @@ sub _validate_and_create_account
     my $first_name  = $cgix->param ('first_name');
     my $family_name = $cgix->param ('family_name');
     my $sql = 'UPDATE Editor SET First_Name = ?, Family_Name = ? WHERE Login = ?';
-    my $dbh = lib::sql::DBH->get();
+    my $dbh = MKDoc::SQL::DBH->get();
     my $sth = $dbh->prepare ($sql);
     $sth->execute ($first_name, $family_name, $self->{user}->login());
     
