@@ -1,38 +1,14 @@
 # -------------------------------------------------------------------------------------
 # flo::plugin::Account::Subscribe
 # -------------------------------------------------------------------------------------
-# Author : Steve Purkis <spurkis@mkdoc.com>, Jean-Michel Hiver
+# Author : Steve Purkis <spurkis@mkdoc.com>, Jean-Michel Hiver <jhiver@mkdoc.com>
 # Copyright : (c) MKDoc Holdings Ltd, 2003.
-#
-# This file is part of MKDoc. 
-# 
-# MKDoc is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-# 
-# MKDoc is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with MKDoc; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
 # -------------------------------------------------------------------------------------
 package flo::plugin::Account::Subscribe;
 use flo::Record::Ticket;
 use flo::Record::Editor;
 use flo::Standard;
 
-# pull in Mail::CheckUser and remember whether it worked or not
-use vars qw /$HAVE_CHECKMAIL/;
-BEGIN {
-    eval "use Mail::CheckUser";
-    $HAVE_CHECKMAIL = 1 unless ($@);
-}
-
 use Carp;
 use Petal;
 use Petal::Mail;
@@ -88,26 +64,14 @@ sub http_post
 	return $self->http_get();
     };
     
-    ($email =~ /[^A-Za-z0-9'@._+-]/) and do {
+    ($email =~ /[^A-Za-z0-9@._-]/) and do {
 	new MKDoc::Ouch 'subscribe/malformed_email';
 	return $self->http_get();
     };
-
-    if ($HAVE_CHECKMAIL) {
-        # setup Mail::CheckUser options
-        local $Mail::CheckUser::Timeout = 5;
-        
-        # check the address using Mail::CheckUser
-        unless(Mail::CheckUser::check_email($email)) {
-            new MKDoc::Ouch 'user/email/advanced_checks';
-            return $self->http_get();
-        }
-    }
-
+    
     $self->{email} = $email;
     $self->{ticket} = $self->_create_ticket ($email);
     $self->_send_mail ($self->{ticket});
-
     return $self->http_get;
 }
 
