@@ -1,26 +1,9 @@
 # -------------------------------------------------------------------------------------
 # flo::plugin::Admin::Delete
 # -------------------------------------------------------------------------------------
-# Author : Jean-Michel Hiver
+# Author : Jean-Michel Hiver <jhiver@mkdoc.com>
 # Copyright : (c) MKDoc Holdings Ltd, 2003
 #
-# This file is part of MKDoc. 
-# 
-# MKDoc is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-# 
-# MKDoc is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with MKDoc; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-#
 # Lets an editor delete the current document. Redirects to the parent document.
 # -------------------------------------------------------------------------------------
 package flo::plugin::Admin::Delete;
@@ -167,7 +150,7 @@ sub redirectable_document_list
     my $self = shift;
     my $document_t = flo::Standard::table ('Document');
     my $document   = flo::Standard::current_document();
-    my $dbh = lib::sql::DBH->get();
+    my $dbh = MKDoc::SQL::DBH->get();
     my $sth = $dbh->prepare_cached ('SELECT * FROM Document WHERE ID != ? ORDER BY (Full_Path)');
     $sth->execute ($document->id());
     my @res = ();
