@@ -1,26 +1,9 @@
 # -------------------------------------------------------------------------------------
 # flo::plugin::Admin::Move
 # -------------------------------------------------------------------------------------
-# Author : Jean-Michel Hiver
+# Author : Jean-Michel Hiver <jhiver@mkdoc.com>
 # Copyright : (c) MKDoc Holdings Ltd, 2003
 #
-# This file is part of MKDoc. 
-# 
-# MKDoc is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-# 
-# MKDoc is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with MKDoc; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-#
 # Lets an editor delete the current document. Redirects to the parent document.
 # -------------------------------------------------------------------------------------
 package flo::plugin::Admin::Move;
@@ -160,10 +143,10 @@ sub movable_document_list
 {
     my $self = shift;
     
-    use lib::sql::Condition;
+    use MKDoc::SQL::Condition;
     my $document_t = flo::Standard::table ('Document');
     my $document   = flo::Standard::current_document();
-    my $condition  = new lib::sql::Condition();
+    my $condition  = new MKDoc::SQL::Condition();
     $condition->add ('Full_Path', 'NOT LIKE', $document->path() . '%');
     
     my $query = $document_t->select (
