@@ -1,26 +1,9 @@
 # -------------------------------------------------------------------------------------
 # flo::plugin::Admin::Sort
 # -------------------------------------------------------------------------------------
-# Author : Jean-Michel Hiver
+# Author : Jean-Michel Hiver <jhiver@mkdoc.com>
 # Copyright : (c) MKDoc Holdings Ltd, 2003
 #
-# This file is part of MKDoc. 
-# 
-# MKDoc is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-# 
-# MKDoc is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with MKDoc; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-#
 # Lets an editor manually sort the child documents of the current document.
 # -------------------------------------------------------------------------------------
 package flo::plugin::Admin::Sort;
@@ -90,7 +73,7 @@ sub http_post
 	$document->set_sort_method (flo::Record::Document::SORT_METHOD_POSITION());
 	$document_t->modify ($document);
 	
-	my $dbh = lib::sql::DBH->get();
+	my $dbh = MKDoc::SQL::DBH->get();
 	my $sth = $dbh->prepare_cached ('UPDATE Document SET Sibling_Position=? WHERE ID=?');
 	my @children = $self->children();
 	for (my $i=0; $i < @children; $i++)
