@@ -2,25 +2,11 @@
 # flo::plugin::Error
 # -------------------------------------------------------------------------------------
 #
-#       Author : Jean-Michel Hiver.
+#       Author : Jean-Michel Hiver (jhiver@mkdoc.com).
 #    Copyright : (c) MKDoc Holdings Ltd, 2003
 # 
-# This file is part of MKDoc. 
-# 
-# MKDoc is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-# 
-# MKDoc is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with MKDoc; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
+#      Unauthorized modification, use, reuse, distribution or redistribution
+#      of this module is stricly forbidden
 #
 #    Description:
 #
@@ -67,7 +53,9 @@ sub run
     
     print <<EOF;
 Status: $status
-Content-Type: text/html; charset=UTF-8
+Content-Type: text/plain
+
+$@
 EOF
     return 'TERMINATE';
 }
