@@ -1,25 +1,8 @@
 # -------------------------------------------------------------------------------------
 # flo::plugin::Headlines
 # -------------------------------------------------------------------------------------
-# Author : Chris Croome <chris@mkdoc.com>, Jean-Michel Hiver
+# Author : Chris Croome <chris@mkdoc.com>, Jean-Michel Hiver <jhiver@mkdoc.com>
 # Copyright : (c) MKDoc Holdings Ltd, 2003
-#
-# This file is part of MKDoc. 
-# 
-# MKDoc is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-# 
-# MKDoc is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with MKDoc; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
 # -------------------------------------------------------------------------------------
 package flo::plugin::Headlines;
 use strict;
@@ -94,8 +77,8 @@ sub items
 {
     my $self = shift;
     
-    use lib::sql::Condition;
-    my $cond = new lib::sql::Condition;
+    use MKDoc::SQL::Condition;
+    my $cond = new MKDoc::SQL::Condition;
     my $doc  = flo::Standard::current_document();
     $cond->add ('Full_Path', 'LIKE', $doc->path() . '_%');
     
