@@ -4,23 +4,9 @@
 #
 #       Author : Alexandre Girard (agirard@popmail.com)
 #    Copyright : (c) MKDoc Holdings Ltd, 2001
-#
-# This file is part of MKDoc. 
 # 
-# MKDoc is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-# 
-# MKDoc is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with MKDoc; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
+#      Unauthorized modification, use, reuse, distribution or redistribution
+#      of this module is stricly forbidden
 #
 #    Description:
 #
@@ -56,7 +42,7 @@ sub http_get
     };
     
     my $sql = 'SELECT Full_Path FROM Document';
-    my $dbh = lib::sql::DBH->get;
+    my $dbh = MKDoc::SQL::DBH->get;
     my $sth = $dbh->prepare_cached ($sql);
     $sth->execute();
     
