@@ -1,26 +1,9 @@
 # -------------------------------------------------------------------------------------
 # flo::plugin::Search
 # -------------------------------------------------------------------------------------
-# Author : Jean-Michel Hiver
+# Author : Jean-Michel Hiver <jhiver@mkdoc.com>
 # Copyright : (c) MKDoc Holdings Ltd, 2003
 #
-# This file is part of MKDoc. 
-# 
-# MKDoc is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-# 
-# MKDoc is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with MKDoc; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-#
 # A plugin that deals with search requests and builds search result pages
 # -------------------------------------------------------------------------------------
 package flo::plugin::Search;
@@ -98,7 +81,7 @@ sub results
 	my $limit  = $self->per_page();
 	my $offset = ($self->page() - 1) * $limit;
 	
-	my $dbh   = lib::sql::DBH->get();
+	my $dbh   = MKDoc::SQL::DBH->get();
 	my $narrw = $self->narrow_prepared();
 	my $where = $self->keywords_prepared();
 	my $sql   = <<EOF;
@@ -134,7 +117,6 @@ EOF
 	    my $doc = $doc_t->get ($arryref->[0]);
 	    $doc->{score} = $arryref->[1];
 	    push @res, $doc if ($doc->is_showable());
-            push @res, $doc if ($doc->is_hidden and $self->user and $self->user->is_editor);
 	}
 	
 	$self->{'.number_of_results'} = scalar @res;
