@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 use strict;
 use warnings;
-use MKDoc::Handler::Initialize;
+use MKDoc::Init::DBI;
 use MKDoc::Site::Check::Redirect;
 use MKDoc::Util::Site_List;
 
@@ -12,7 +12,7 @@ main();
 sub main
 {
     defined $ENV{SITE_DIR} and return do {
-        MKDoc::Handler::Initialize::handler();
+	MKDoc::Init::DBI->init();
         MKDoc::Site::Check::Redirect->check();
     };
     
