@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 use strict;
 use warnings;
-use MKDoc::Handler::Initialize;
+use MKDoc::Init::DBI;
 use MKDoc::Site::Check::RelationShips;
 use MKDoc::Util::Site_List;
 $ENV{MKDOC_DIR} || die 'MKDOC_DIR is not defined!';
@@ -11,7 +11,7 @@ main();
 sub main
 {
     defined $ENV{SITE_DIR} and return do {
-        MKDoc::Handler::Initialize::handler();
+        MKDoc::Init::DBI->init();
         MKDoc::Site::Check::RelationShips->check();
     };
     
