@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 use strict;
 use warnings;
-use MKDoc::Handler::Initialize;
+use MKDoc::Init::DBI;
 use flo::Standard;
 use MKDoc::Util::Text2HTML;
 use MKDoc::Stemmer;
@@ -13,15 +13,13 @@ main();
 sub main
 {
     defined $ENV{SITE_DIR} and return do {
-        MKDoc::Handler::Initialize::handler();
+	MKDoc::Init::DBI->init();
         index_remove();
         index_update();
     };
     
     foreach my $mkdoc_site (site_list())
     {
-        opendir (DIR, "$mkdoc_site") || next;
-        closedir DIR;
         print "INDEXING: $mkdoc_site\n";
         $ENV{SITE_DIR} = $mkdoc_site;
         main();
@@ -55,7 +53,7 @@ sub site_list
 sub index_remove
 {
     my @to_remove = removed_document_ids();
-    my $dbh = lib::sql::DBH->get();
+    my $dbh = MKDoc::SQL::DBH->get();
     my $sql = 'DELETE FROM Document_Index WHERE Record_ID = ?';
     my $sth = $dbh->prepare ($sql);
     for (removed_document_ids())
@@ -68,7 +66,7 @@ sub index_remove
 
 sub index_update
 {
-    my $dbh = lib::sql::DBH->get();
+    my $dbh = MKDoc::SQL::DBH->get();
     my $sql = 'SELECT ID, Full_Path From Document WHERE Date_Last_Modified > ?';
     my $sth = $dbh->prepare ($sql);
     $sth->execute (reindex_date());
@@ -92,7 +90,7 @@ sub removed_document_ids
 
 sub distinct_document_ids
 {
-    my $dbh = lib::sql::DBH->get();
+    my $dbh = MKDoc::SQL::DBH->get();
     my $sql = 'SELECT DISTINCT ID FROM Document';
     my $sth = $dbh->prepare ($sql);
     $sth->execute();
@@ -104,7 +102,7 @@ sub distinct_document_ids
 
 sub distinct_index_document_ids
 {
-    my $dbh = lib::sql::DBH->get();
+    my $dbh = MKDoc::SQL::DBH->get();
     my $sql = 'SELECT DISTINCT Record_ID FROM Document_Index';
     my $sth = $dbh->prepare ($sql);
     $sth->execute();
@@ -118,7 +116,7 @@ sub distinct_index_document_ids
 sub index_delete_keywords
 {
     my $doc_id = shift;
-    my $dbh    = lib::sql::DBH->get();
+    my $dbh    = MKDoc::SQL::DBH->get();
 
     my $sql = "DELETE FROM Document_Index WHERE Record_ID=?";
     my $sth = $dbh->prepare ($sql);
@@ -132,7 +130,7 @@ sub index_insert_keywords
     my $doc_t  = flo::Standard::table ('Document');
     my $doc    = $doc_t->get ($doc_id) or (Carp::cluck "Cannot get document with ID: $doc_id" and return);
 
-    my $dbh    = lib::sql::DBH->get();
+    my $dbh    = MKDoc::SQL::DBH->get();
     my $sth    = $dbh->prepare ('INSERT INTO Document_Index VALUES (NULL, ?, ?, ?)');
     foreach my $col (sort keys %{$doc})
     {
