@@ -154,7 +154,7 @@ sub setup_files
         qq |export SITE_DIR="$site_dir"|,
         qq |export SERVER_ADMIN="$server_admin"|,
         qq |export PUBLIC_DOMAIN="$public_domain"|,
-        qq |export USER_DOMAIN="$user_domain"|, ''
+        qq |export USER_DOMAIN="$user_domain"|,
     );
 
     close FP;
