@@ -1,20 +1,10 @@
 #!/usr/bin/perl
 use strict;
 use warnings;
-use Carp;
+use MKDoc::Init::DBI;
+use flo::Standard;
 
-$ENV{MKDOC_DIR}   || croak 'Environment variable MKDOC_DIR is not defined';
-$ENV{SERVER_NAME} || croak 'Environment variable SERVER_NAME is not defined';
-
-unshift @INC, $ENV{MKDOC_DIR};
-eval <<EOF;
-    use MKDoc;
-    use flo::Standard;      
-EOF
-
-croak $@ if (defined $@ and $@);
-		       
-MKDoc->init;
+MKDoc::Init::DBI->init;
 
 main();
 
